@@ -18,7 +18,7 @@ import xarray
 from rasterio import DatasetReader
 from rasterio.crs import CRS
 from rasterio.enums import Resampling
-from ruamel.yaml import CommentedMap
+from ruamel.yaml.comments import CommentedMap
 from shapely.geometry.base import BaseGeometry
 
 import eodatasets3
@@ -1694,7 +1694,7 @@ class DatasetAssembler(DatasetPrepare):
 
         # Match the lower r/w permission bits to the output folder.
         # (Temp directories default to 700 otherwise.)
-        self._work_path.chmod(self._target_collection_path().stat().st_mode & 0o777)
+        self._work_path.chmod(self._target_collection_path().stat().st_mode & 0o7777)
 
         # GDAL writes extra metadata in aux files,
         # but we consider it a mistake if you're using those extensions.
