@@ -91,19 +91,148 @@ def test_prepare_l8_l1_usgs_tarball(l1_ls8_folder, l1_ls8_folder_md_expected):
     )
 
 
-def test_prepare_l8_l1_c2(
-    tmp_path: Path, l1_c2_ls8_folder: Path, l1_c2_ls8_usgs_expected: Dict
-):
+def test_prepare_l8_l1_c2(tmp_path: Path, l1_c2_ls8_folder: Path):
     """Run prepare script with a source telemetry data and unique producer."""
     assert l1_c2_ls8_folder.exists(), "Test data missing(?)"
 
     output_path = tmp_path
     expected_metadata_path = (
         output_path
-        / "090"
-        / "084"
-        / "LC08_L1TP_090084_20160121_20200907_02_T1.odc-metadata.yaml"
+        / "089"
+        / "074"
+        / "LC08_L1GT_089074_20220506_20220512_02_T2.odc-metadata.yaml"
     )
+
+    expected_doc = {
+        "$schema": "https://schemas.opendatacube.org/dataset",
+        "id": "5e1359de-0f91-5988-a6f0-8a0a840906f4",
+        "label": "usgs_ls8c_level1_2-0-20220512_089074_2022-05-06",
+        "product": {
+            "name": "usgs_ls8c_level1_2",
+            "href": "https://collections.dea.ga.gov.au/product/usgs_ls8c_level1_2",
+        },
+        "crs": "epsg:32656",
+        "grids": {
+            "default": {
+                "shape": [60, 60],
+                "transform": [
+                    3860.5,
+                    0.0,
+                    594285.0,
+                    0.0,
+                    -3910.5,
+                    -2121285.0,
+                    0.0,
+                    0.0,
+                    1.0,
+                ],
+            },
+            "panchromatic": {
+                "shape": [60, 60],
+                "transform": [
+                    3860.2500000000005,
+                    0.0,
+                    594292.5,
+                    0.0,
+                    -3910.25,
+                    -2121292.5,
+                    0.0,
+                    0.0,
+                    1.0,
+                ],
+            },
+        },
+        "geometry": {
+            "type": "Polygon",
+            "coordinates": (
+                (
+                    (635871.100911986, -2328431.8044824763),
+                    (598807.3537167514, -2315758.4765276713),
+                    (594285.0, -2314216.125490317),
+                    (594285.0, -2294479.549612592),
+                    (629132.1230216483, -2128210.3416854665),
+                    (634001.1369104853, -2121285.0),
+                    (671771.6827861228, -2121285.0),
+                    (759108.8670950294, -2143693.8957929504),
+                    (819064.1631236447, -2156587.0374096073),
+                    (824424.9683929395, -2160452.642015061),
+                    (825915.0, -2160834.95297774),
+                    (825915.0, -2197333.359107589),
+                    (818095.1372109791, -2231658.3131009457),
+                    (784506.5705934291, -2355915.0),
+                    (764094.013739199, -2355915.0),
+                    (647454.7800689514, -2332349.7060506954),
+                    (636125.9731110331, -2328486.0106703877),
+                    (635871.100911986, -2328431.8044824763),
+                ),
+            ),
+        },
+        "properties": {
+            "datetime": "2022-05-06T23:39:59.285133",
+            "eo:cloud_cover": 86.35,
+            "eo:gsd": 15.0,
+            "eo:instrument": "OLI_TIRS",
+            "eo:platform": "landsat-8",
+            "eo:sun_azimuth": 39.80724521,
+            "eo:sun_elevation": 43.24426868,
+            "landsat:collection_category": "T2",
+            "landsat:collection_number": 2,
+            "landsat:data_type": "L1GT",
+            "landsat:landsat_product_id": "LC08_L1GT_089074_20220506_20220512_02_T2",
+            "landsat:landsat_scene_id": "LC80890742022126LGN00",
+            "landsat:processing_software_version": "LPGS_15.6.0",
+            "landsat:station_id": "LGN",
+            "landsat:wrs_path": 89,
+            "landsat:wrs_row": 74,
+            "odc:dataset_version": "2.0.20220512",
+            "odc:file_format": "GeoTIFF",
+            "odc:processing_datetime": "2022-05-12T14:00:17",
+            "odc:producer": "usgs.gov",
+            "odc:product_family": "level1",
+            "odc:region_code": "089074",
+        },
+        "measurements": {
+            "blue": {"path": "LC08_L1GT_089074_20220506_20220512_02_T2_B2.TIF"},
+            "cirrus": {"path": "LC08_L1GT_089074_20220506_20220512_02_T2_B9.TIF"},
+            "coastal_aerosol": {
+                "path": "LC08_L1GT_089074_20220506_20220512_02_T2_B1.TIF"
+            },
+            "green": {"path": "LC08_L1GT_089074_20220506_20220512_02_T2_B3.TIF"},
+            "lwir_1": {"path": "LC08_L1GT_089074_20220506_20220512_02_T2_B10.TIF"},
+            "lwir_2": {"path": "LC08_L1GT_089074_20220506_20220512_02_T2_B11.TIF"},
+            "nir": {"path": "LC08_L1GT_089074_20220506_20220512_02_T2_B5.TIF"},
+            "panchromatic": {
+                "path": "LC08_L1GT_089074_20220506_20220512_02_T2_B8.TIF",
+                "grid": "panchromatic",
+            },
+            "qa_radsat": {
+                "path": "LC08_L1GT_089074_20220506_20220512_02_T2_QA_RADSAT.TIF"
+            },
+            "quality": {
+                "path": "LC08_L1GT_089074_20220506_20220512_02_T2_QA_PIXEL.TIF"
+            },
+            "red": {"path": "LC08_L1GT_089074_20220506_20220512_02_T2_B4.TIF"},
+            "solar_azimuth": {
+                "path": "LC08_L1GT_089074_20220506_20220512_02_T2_SAA.TIF"
+            },
+            "solar_zenith": {
+                "path": "LC08_L1GT_089074_20220506_20220512_02_T2_SZA.TIF"
+            },
+            "swir_1": {"path": "LC08_L1GT_089074_20220506_20220512_02_T2_B6.TIF"},
+            "swir_2": {"path": "LC08_L1GT_089074_20220506_20220512_02_T2_B7.TIF"},
+            "view_azimuth": {
+                "path": "LC08_L1GT_089074_20220506_20220512_02_T2_VAA.TIF"
+            },
+            "view_zenith": {"path": "LC08_L1GT_089074_20220506_20220512_02_T2_VZA.TIF"},
+        },
+        "accessories": {
+            "metadata:landsat_mtl": {
+                "path": "LC08_L1GT_089074_20220506_20220512_02_T2_MTL.txt"
+            }
+        },
+        "lineage": {},
+    }
+
     check_prepare_outputs(
         invoke_script=landsat_l1_prepare.main,
         run_args=[
@@ -113,7 +242,7 @@ def test_prepare_l8_l1_c2(
             "usgs.gov",
             l1_c2_ls8_folder,
         ],
-        expected_doc=l1_c2_ls8_usgs_expected,
+        expected_doc=expected_doc,
         expected_metadata_path=expected_metadata_path,
     )
 
@@ -128,7 +257,6 @@ def l9_expected():
             "name": "usgs_ls9c_level1_2",
             "href": "https://collections.dea.ga.gov.au/product/usgs_ls9c_level1_2",
         },
-        "crs": "epsg:32650",
         "geometry": {
             "type": "Polygon",
             "coordinates": (
@@ -156,6 +284,7 @@ def l9_expected():
                 ),
             ),
         },
+        "crs": "epsg:32650",
         "grids": {
             "default": {
                 "shape": [60, 60],
@@ -228,12 +357,25 @@ def l9_expected():
                 "path": "LC09_L1TP_112081_20220209_20220209_02_T1_B8.TIF",
                 "grid": "panchromatic",
             },
+            "qa_radsat": {
+                "path": "LC09_L1TP_112081_20220209_20220209_02_T1_QA_RADSAT.TIF"
+            },
             "quality": {
                 "path": "LC09_L1TP_112081_20220209_20220209_02_T1_QA_PIXEL.TIF"
             },
             "red": {"path": "LC09_L1TP_112081_20220209_20220209_02_T1_B4.TIF"},
+            "solar_azimuth": {
+                "path": "LC09_L1TP_112081_20220209_20220209_02_T1_SAA.TIF"
+            },
+            "solar_zenith": {
+                "path": "LC09_L1TP_112081_20220209_20220209_02_T1_SZA.TIF"
+            },
             "swir_1": {"path": "LC09_L1TP_112081_20220209_20220209_02_T1_B6.TIF"},
             "swir_2": {"path": "LC09_L1TP_112081_20220209_20220209_02_T1_B7.TIF"},
+            "view_azimuth": {
+                "path": "LC09_L1TP_112081_20220209_20220209_02_T1_VAA.TIF"
+            },
+            "view_zenith": {"path": "LC09_L1TP_112081_20220209_20220209_02_T1_VZA.TIF"},
         },
         "accessories": {
             "metadata:landsat_mtl": {
@@ -448,18 +590,10 @@ def expected_lc08_l2_c2_post_20210507_folder(
     org_code = organisation.split(".")[0]
     product_name = f"{org_code}_ls8c_level{leveln_collection}_{collection}"
     processing_datetime = datetime(2021, 5, 8, 11, 5, 47)
-    cloud_cover = 72.57
-    points_model = 35
-    points_version = 5
-    rmse_model_x = 5.974
-    rmse_model_y = 4.276
-    software_version = "LPGS_15.4.0"
-    uuid = "d4ff459f-67e0-57df-af73-dfef14ad9c47"
-    quality_tag = "QA_PIXEL"
     processing_date = processing_datetime.strftime("%Y%m%d")
     return {
         "$schema": "https://schemas.opendatacube.org/dataset",
-        "id": uuid,
+        "id": "d4ff459f-67e0-57df-af73-dfef14ad9c47",
         "label": f"{product_name}-0-{processing_date}_098084_2021-05-03",
         "product": {
             "name": product_name,
@@ -475,7 +609,7 @@ def expected_lc08_l2_c2_post_20210507_folder(
             "odc:producer": organisation,
             "odc:product_family": "level2",
             "odc:region_code": "098084",
-            "eo:cloud_cover": cloud_cover,
+            "eo:cloud_cover": 72.57,
             "eo:gsd": 30.0,
             "eo:instrument": "OLI_TIRS",
             "eo:platform": "landsat-8",
@@ -485,13 +619,13 @@ def expected_lc08_l2_c2_post_20210507_folder(
             "landsat:collection_category": "T1",
             "landsat:collection_number": int(leveln_collection),
             "landsat:data_type": "L2SP",
-            "landsat:geometric_rmse_model_x": rmse_model_x,
-            "landsat:geometric_rmse_model_y": rmse_model_y,
-            "landsat:ground_control_points_model": points_model,
-            "landsat:ground_control_points_version": points_version,
+            "landsat:geometric_rmse_model_x": 5.974,
+            "landsat:geometric_rmse_model_y": 4.276,
+            "landsat:ground_control_points_model": 35,
+            "landsat:ground_control_points_version": 5,
             "landsat:landsat_product_id": f"LC08_L2SP_098084_20210503_{processing_date}_0{leveln_collection}_T1",
             "landsat:landsat_scene_id": "LC80980842021123LGN00",
-            "landsat:processing_software_version": software_version,
+            "landsat:processing_software_version": "LPGS_15.4.0",
             "landsat:station_id": "LGN",
             "landsat:wrs_path": 98,
             "landsat:wrs_row": 84,
@@ -533,18 +667,48 @@ def expected_lc08_l2_c2_post_20210507_folder(
             },
         },
         "measurements": {
+            "atmos_transmittance": {
+                "path": offset(
+                    l2_c2_ls8_folder,
+                    f"LC08_L2SP_098084_20210503_{processing_date}_0{leveln_collection}_T1_ST_ATRAN.TIF",
+                )
+            },
             "blue": {
                 "path": offset(
                     l2_c2_ls8_folder,
                     f"LC08_L2SP_098084_20210503_{processing_date}_0{leveln_collection}_T1_SR_B2.TIF",
                 )
             },
+            "cloud_distance": {
+                "path": offset(
+                    l2_c2_ls8_folder,
+                    f"LC08_L2SP_098084_20210503_{processing_date}_0{leveln_collection}_T1_ST_CDIST.TIF",
+                )
+            },
             "coastal_aerosol": {
                 "path": offset(
                     l2_c2_ls8_folder,
                     f"LC08_L2SP_098084_20210503_{processing_date}_0{leveln_collection}_T1_SR_B1.TIF",
                 )
             },
+            "downwell_radiance": {
+                "path": offset(
+                    l2_c2_ls8_folder,
+                    f"LC08_L2SP_098084_20210503_{processing_date}_0{leveln_collection}_T1_ST_DRAD.TIF",
+                )
+            },
+            "emissivity": {
+                "path": offset(
+                    l2_c2_ls8_folder,
+                    f"LC08_L2SP_098084_20210503_{processing_date}_0{leveln_collection}_T1_ST_EMIS.TIF",
+                )
+            },
+            "emissivity_stdev": {
+                "path": offset(
+                    l2_c2_ls8_folder,
+                    f"LC08_L2SP_098084_20210503_{processing_date}_0{leveln_collection}_T1_ST_EMSD.TIF",
+                )
+            },
             "green": {
                 "path": offset(
                     l2_c2_ls8_folder,
@@ -569,10 +733,22 @@ def expected_lc08_l2_c2_post_20210507_folder(
                     f"LC08_L2SP_098084_20210503_{processing_date}_0{leveln_collection}_T1_SR_QA_AEROSOL.TIF",
                 )
             },
+            "qa_radsat": {
+                "path": offset(
+                    l2_c2_ls8_folder,
+                    f"LC08_L2SP_098084_20210503_{processing_date}_0{leveln_collection}_T1_QA_RADSAT.TIF",
+                )
+            },
+            "qa_temperature": {
+                "path": offset(
+                    l2_c2_ls8_folder,
+                    f"LC08_L2SP_098084_20210503_{processing_date}_0{leveln_collection}_T1_ST_QA.TIF",
+                )
+            },
             "quality": {
                 "path": offset(
                     l2_c2_ls8_folder,
-                    f"LC08_L2SP_098084_20210503_{processing_date}_0{leveln_collection}_T1_{quality_tag}.TIF",
+                    f"LC08_L2SP_098084_20210503_{processing_date}_0{leveln_collection}_T1_QA_PIXEL.TIF",
                 )
             },
             "red": {
@@ -593,56 +769,51 @@ def expected_lc08_l2_c2_post_20210507_folder(
                     f"LC08_L2SP_098084_20210503_{processing_date}_0{leveln_collection}_T1_SR_B7.TIF",
                 )
             },
+            "thermal_radiance": {
+                "path": offset(
+                    l2_c2_ls8_folder,
+                    f"LC08_L2SP_098084_20210503_{processing_date}_0{leveln_collection}_T1_ST_TRAD.TIF",
+                )
+            },
+            "upwell_radiance": {
+                "path": offset(
+                    l2_c2_ls8_folder,
+                    f"LC08_L2SP_098084_20210503_{processing_date}_0{leveln_collection}_T1_ST_URAD.TIF",
+                )
+            },
         },
         "accessories": {
             "metadata:landsat_mtl": {
-                "path": f"LC08_L2SP_098084_20210503_{processing_date}_0{leveln_collection}_T1_MTL.txt"
+                "path": offset(
+                    l2_c2_ls8_folder,
+                    f"LC08_L2SP_098084_20210503_{processing_date}_0{leveln_collection}_T1_MTL.txt",
+                )
             }
         },
         "lineage": lineage or {},
     }
 
 
-def expected_lt05_l2_c2_folder(
-    l2_c2_ls8_folder: Path = None,
-    offset: Callable[[Path, str], str] = relative_offset,
-    organisation="usgs.gov",
-    collection="2",
-    leveln_collection="2",
-    lineage=None,
-):
-    """ """
-    org_code = organisation.split(".")[0]
-    product_name = f"{org_code}_ls5t_level{leveln_collection}_{collection}"
-    processing_datetime = datetime(2020, 9, 9, 10, 36, 59)
-    cloud_cover = 12.0
-    points_model = 965
-    points_version = 5
-    rmse_model_x = 3.085
-    rmse_model_y = 2.977
-    software_version = "LPGS_15.3.1c"
-    uuid = "b08b3f9e-b00c-5a67-88d8-a889f0e79d00"
-    quality_tag = "QA_PIXEL"
-    processing_date = processing_datetime.strftime("%Y%m%d")
+def expected_lt05_l2_c2_folder():
     return {
         "$schema": "https://schemas.opendatacube.org/dataset",
-        "id": uuid,
-        "label": f"{product_name}-0-{processing_date}_090084_1998-03-08",
+        "id": "b08b3f9e-b00c-5a67-88d8-a889f0e79d00",
+        "label": "usgs_ls5t_level2_2-0-20200909_090084_1998-03-08",
         "product": {
-            "name": product_name,
-            "href": f"https://collections.dea.ga.gov.au/product/{product_name}",
+            "name": "usgs_ls5t_level2_2",
+            "href": "https://collections.dea.ga.gov.au/product/usgs_ls5t_level2_2",
         },
         "properties": {
             "datetime": datetime(1998, 3, 8, 23, 26, 47, 294081),
             # The minor version comes from the processing date,
             # as used in filenames to distinguish reprocesses.
-            "odc:dataset_version": f"{collection}.0.{processing_date}",
+            "odc:dataset_version": "2.0.20200909",
             "odc:file_format": "GeoTIFF",
-            "odc:processing_datetime": processing_datetime,
-            "odc:producer": organisation,
+            "odc:processing_datetime": (datetime(2020, 9, 9, 10, 36, 59)),
+            "odc:producer": "usgs.gov",
             "odc:product_family": "level2",
             "odc:region_code": "090084",
-            "eo:cloud_cover": cloud_cover,
+            "eo:cloud_cover": 12.0,
             "eo:gsd": 30.0,
             "eo:instrument": "TM",
             "eo:platform": "landsat-5",
@@ -650,15 +821,15 @@ def expected_lt05_l2_c2_folder(
             "eo:sun_elevation": 41.583_263_99,
             "landsat:algorithm_source_surface_reflectance": "LEDAPS_3.4.0",
             "landsat:collection_category": "T1",
-            "landsat:collection_number": int(leveln_collection),
+            "landsat:collection_number": int(2),
             "landsat:data_type": "L2SP",
-            "landsat:geometric_rmse_model_x": rmse_model_x,
-            "landsat:geometric_rmse_model_y": rmse_model_y,
-            "landsat:ground_control_points_model": points_model,
-            "landsat:ground_control_points_version": points_version,
-            "landsat:landsat_product_id": f"LT05_L2SP_090084_19980308_{processing_date}_0{leveln_collection}_T1",
+            "landsat:geometric_rmse_model_x": 3.085,
+            "landsat:geometric_rmse_model_y": 2.977,
+            "landsat:ground_control_points_model": 965,
+            "landsat:ground_control_points_version": 5,
+            "landsat:landsat_product_id": "LT05_L2SP_090084_19980308_20200909_02_T1",
             "landsat:landsat_scene_id": "LT50900841998067ASA00",
-            "landsat:processing_software_version": software_version,
+            "landsat:processing_software_version": "LPGS_15.3.1c",
             "landsat:station_id": "ASA",
             "landsat:wrs_path": 90,
             "landsat:wrs_row": 84,
@@ -697,115 +868,79 @@ def expected_lt05_l2_c2_folder(
         },
         "measurements": {
             "atmos_opacity": {
-                "path": offset(
-                    l2_c2_ls8_folder,
-                    f"LT05_L2SP_090084_19980308_{processing_date}_0{leveln_collection}_T1_SR_ATMOS_OPACITY.TIF",
-                )
+                "path": "LT05_L2SP_090084_19980308_20200909_02_T1_SR_ATMOS_OPACITY.TIF"
             },
-            "blue": {
-                "path": offset(
-                    l2_c2_ls8_folder,
-                    f"LT05_L2SP_090084_19980308_{processing_date}_0{leveln_collection}_T1_SR_B1.TIF",
-                )
+            "atmos_transmittance": {
+                "path": "LT05_L2SP_090084_19980308_20200909_02_T1_ST_ATRAN.TIF"
             },
-            "green": {
-                "path": offset(
-                    l2_c2_ls8_folder,
-                    f"LT05_L2SP_090084_19980308_{processing_date}_0{leveln_collection}_T1_SR_B2.TIF",
-                )
+            "blue": {"path": "LT05_L2SP_090084_19980308_20200909_02_T1_SR_B1.TIF"},
+            "cloud_distance": {
+                "path": "LT05_L2SP_090084_19980308_20200909_02_T1_ST_CDIST.TIF"
             },
-            "lwir": {
-                "path": offset(
-                    l2_c2_ls8_folder,
-                    f"LT05_L2SP_090084_19980308_{processing_date}_0{leveln_collection}_T1_ST_B6.TIF",
-                )
+            "downwell_radiance": {
+                "path": "LT05_L2SP_090084_19980308_20200909_02_T1_ST_DRAD.TIF"
             },
-            "nir": {
-                "path": offset(
-                    l2_c2_ls8_folder,
-                    f"LT05_L2SP_090084_19980308_{processing_date}_0{leveln_collection}_T1_SR_B4.TIF",
-                )
+            "emissivity": {
+                "path": "LT05_L2SP_090084_19980308_20200909_02_T1_ST_EMIS.TIF"
             },
+            "emissivity_stdev": {
+                "path": "LT05_L2SP_090084_19980308_20200909_02_T1_ST_EMSD.TIF"
+            },
+            "green": {"path": "LT05_L2SP_090084_19980308_20200909_02_T1_SR_B2.TIF"},
+            "lwir": {"path": "LT05_L2SP_090084_19980308_20200909_02_T1_ST_B6.TIF"},
+            "nir": {"path": "LT05_L2SP_090084_19980308_20200909_02_T1_SR_B4.TIF"},
             "qa_cloud": {
-                "path": offset(
-                    l2_c2_ls8_folder,
-                    f"LT05_L2SP_090084_19980308_{processing_date}_0{leveln_collection}_T1_SR_CLOUD_QA.TIF",
-                )
+                "path": "LT05_L2SP_090084_19980308_20200909_02_T1_SR_CLOUD_QA.TIF"
+            },
+            "qa_radsat": {
+                "path": "LT05_L2SP_090084_19980308_20200909_02_T1_QA_RADSAT.TIF"
+            },
+            "qa_temperature": {
+                "path": "LT05_L2SP_090084_19980308_20200909_02_T1_ST_QA.TIF"
             },
             "quality": {
-                "path": offset(
-                    l2_c2_ls8_folder,
-                    f"LT05_L2SP_090084_19980308_{processing_date}_0{leveln_collection}_T1_{quality_tag}.TIF",
-                )
+                "path": "LT05_L2SP_090084_19980308_20200909_02_T1_QA_PIXEL.TIF"
             },
-            "red": {
-                "path": offset(
-                    l2_c2_ls8_folder,
-                    f"LT05_L2SP_090084_19980308_{processing_date}_0{leveln_collection}_T1_SR_B3.TIF",
-                )
+            "red": {"path": "LT05_L2SP_090084_19980308_20200909_02_T1_SR_B3.TIF"},
+            "swir_1": {"path": "LT05_L2SP_090084_19980308_20200909_02_T1_SR_B5.TIF"},
+            "swir_2": {"path": "LT05_L2SP_090084_19980308_20200909_02_T1_SR_B7.TIF"},
+            "thermal_radiance": {
+                "path": "LT05_L2SP_090084_19980308_20200909_02_T1_ST_TRAD.TIF"
             },
-            "swir_1": {
-                "path": offset(
-                    l2_c2_ls8_folder,
-                    f"LT05_L2SP_090084_19980308_{processing_date}_0{leveln_collection}_T1_SR_B5.TIF",
-                )
-            },
-            "swir_2": {
-                "path": offset(
-                    l2_c2_ls8_folder,
-                    f"LT05_L2SP_090084_19980308_{processing_date}_0{leveln_collection}_T1_SR_B7.TIF",
-                )
+            "upwell_radiance": {
+                "path": "LT05_L2SP_090084_19980308_20200909_02_T1_ST_URAD.TIF"
             },
         },
         "accessories": {
             "metadata:landsat_mtl": {
-                "path": f"LT05_L2SP_090084_19980308_{processing_date}_0{leveln_collection}_T1_MTL.txt"
+                "path": "LT05_L2SP_090084_19980308_20200909_02_T1_MTL.txt"
             }
         },
-        "lineage": lineage or {},
+        "lineage": {},
     }
 
 
-def expected_le07_l2_c2_folder(
-    l2_c2_ls8_folder: Path = None,
-    offset: Callable[[Path, str], str] = relative_offset,
-    organisation="usgs.gov",
-    collection="2",
-    leveln_collection="2",
-    lineage=None,
-):
-    """ """
-    org_code = organisation.split(".")[0]
-    product_name = f"{org_code}_ls7e_level{leveln_collection}_{collection}"
-    processing_datetime = datetime(2021, 4, 26, 10, 52, 29)
-    cloud_cover = 6.0
-    points_model = 1240
-    points_version = 5
-    rmse_model_x = 3.08
-    rmse_model_y = 3.663
-    software_version = "LPGS_15.4.0"
-    uuid = "2184a390-3bfc-5393-91fa-e9dae7c3fe39"
-    quality_tag = "QA_PIXEL"
-    processing_date = processing_datetime.strftime("%Y%m%d")
+def expected_le07_l2_c2_folder():
+
     return {
         "$schema": "https://schemas.opendatacube.org/dataset",
-        "id": uuid,
-        "label": f"{product_name}-0-{processing_date}_090084_2021-03-31",
+        "id": "2184a390-3bfc-5393-91fa-e9dae7c3fe39",
+        "label": "usgs_ls7e_level2_2-0-20210426_090084_2021-03-31",
         "product": {
-            "name": product_name,
-            "href": f"https://collections.dea.ga.gov.au/product/{product_name}",
+            "name": "usgs_ls7e_level2_2",
+            "href": "https://collections.dea.ga.gov.au/product/usgs_ls7e_level2_2",
         },
         "properties": {
             "datetime": datetime(2021, 3, 31, 23, 1, 59, 738020),
             # The minor version comes from the processing date,
             # as used in filenames to distinguish reprocesses.
-            "odc:dataset_version": f"{collection}.0.{processing_date}",
+            "odc:dataset_version": "2.0.20210426",
             "odc:file_format": "GeoTIFF",
-            "odc:processing_datetime": processing_datetime,
-            "odc:producer": organisation,
+            "odc:processing_datetime": (datetime(2021, 4, 26, 10, 52, 29)),
+            "odc:producer": "usgs.gov",
             "odc:product_family": "level2",
             "odc:region_code": "090084",
-            "eo:cloud_cover": cloud_cover,
+            "eo:cloud_cover": 6.0,
             "eo:gsd": 30.0,
             "eo:instrument": "ETM",
             "eo:platform": "landsat-7",
@@ -813,15 +948,15 @@ def expected_le07_l2_c2_folder(
             "eo:sun_elevation": 31.970_873_9,
             "landsat:algorithm_source_surface_reflectance": "LEDAPS_3.4.0",
             "landsat:collection_category": "T1",
-            "landsat:collection_number": int(leveln_collection),
+            "landsat:collection_number": int(2),
             "landsat:data_type": "L2SP",
-            "landsat:geometric_rmse_model_x": rmse_model_x,
-            "landsat:geometric_rmse_model_y": rmse_model_y,
-            "landsat:ground_control_points_model": points_model,
-            "landsat:ground_control_points_version": points_version,
-            "landsat:landsat_product_id": f"LE07_L2SP_090084_20210331_{processing_date}_0{leveln_collection}_T1",
+            "landsat:geometric_rmse_model_x": 3.08,
+            "landsat:geometric_rmse_model_y": 3.663,
+            "landsat:ground_control_points_model": 1240,
+            "landsat:ground_control_points_version": 5,
+            "landsat:landsat_product_id": "LE07_L2SP_090084_20210331_20210426_02_T1",
             "landsat:landsat_scene_id": "LE70900842021090ASA00",
-            "landsat:processing_software_version": software_version,
+            "landsat:processing_software_version": "LPGS_15.4.0",
             "landsat:station_id": "ASA",
             "landsat:wrs_path": 90,
             "landsat:wrs_row": 84,
@@ -863,70 +998,53 @@ def expected_le07_l2_c2_folder(
         },
         "measurements": {
             "atmos_opacity": {
-                "path": offset(
-                    l2_c2_ls8_folder,
-                    f"LE07_L2SP_090084_20210331_{processing_date}_0{leveln_collection}_T1_SR_ATMOS_OPACITY.TIF",
-                )
+                "path": "LE07_L2SP_090084_20210331_20210426_02_T1_SR_ATMOS_OPACITY.TIF"
             },
-            "blue": {
-                "path": offset(
-                    l2_c2_ls8_folder,
-                    f"LE07_L2SP_090084_20210331_{processing_date}_0{leveln_collection}_T1_SR_B1.TIF",
-                )
+            "atmos_transmittance": {
+                "path": "LE07_L2SP_090084_20210331_20210426_02_T1_ST_ATRAN.TIF"
             },
-            "green": {
-                "path": offset(
-                    l2_c2_ls8_folder,
-                    f"LE07_L2SP_090084_20210331_{processing_date}_0{leveln_collection}_T1_SR_B2.TIF",
-                )
+            "blue": {"path": "LE07_L2SP_090084_20210331_20210426_02_T1_SR_B1.TIF"},
+            "cloud_distance": {
+                "path": "LE07_L2SP_090084_20210331_20210426_02_T1_ST_CDIST.TIF"
             },
-            "lwir": {
-                "path": offset(
-                    l2_c2_ls8_folder,
-                    f"LE07_L2SP_090084_20210331_{processing_date}_0{leveln_collection}_T1_ST_B6.TIF",
-                )
+            "downwell_radiance": {
+                "path": "LE07_L2SP_090084_20210331_20210426_02_T1_ST_DRAD.TIF"
             },
-            "nir": {
-                "path": offset(
-                    l2_c2_ls8_folder,
-                    f"LE07_L2SP_090084_20210331_{processing_date}_0{leveln_collection}_T1_SR_B4.TIF",
-                )
+            "emissivity": {
+                "path": "LE07_L2SP_090084_20210331_20210426_02_T1_ST_EMIS.TIF"
             },
+            "emissivity_stdev": {
+                "path": "LE07_L2SP_090084_20210331_20210426_02_T1_ST_EMSD.TIF"
+            },
+            "green": {"path": "LE07_L2SP_090084_20210331_20210426_02_T1_SR_B2.TIF"},
+            "lwir": {"path": "LE07_L2SP_090084_20210331_20210426_02_T1_ST_B6.TIF"},
+            "nir": {"path": "LE07_L2SP_090084_20210331_20210426_02_T1_SR_B4.TIF"},
             "qa_cloud": {
-                "path": offset(
-                    l2_c2_ls8_folder,
-                    f"LE07_L2SP_090084_20210331_{processing_date}_0{leveln_collection}_T1_SR_CLOUD_QA.TIF",
-                )
+                "path": "LE07_L2SP_090084_20210331_20210426_02_T1_SR_CLOUD_QA.TIF"
+            },
+            "qa_radsat": {
+                "path": "LE07_L2SP_090084_20210331_20210426_02_T1_QA_RADSAT.TIF"
+            },
+            "qa_temperature": {
+                "path": "LE07_L2SP_090084_20210331_20210426_02_T1_ST_QA.TIF"
             },
             "quality": {
-                "path": offset(
-                    l2_c2_ls8_folder,
-                    f"LE07_L2SP_090084_20210331_{processing_date}_0{leveln_collection}_T1_{quality_tag}.TIF",
-                )
+                "path": "LE07_L2SP_090084_20210331_20210426_02_T1_QA_PIXEL.TIF"
             },
-            "red": {
-                "path": offset(
-                    l2_c2_ls8_folder,
-                    f"LE07_L2SP_090084_20210331_{processing_date}_0{leveln_collection}_T1_SR_B3.TIF",
-                )
+            "red": {"path": "LE07_L2SP_090084_20210331_20210426_02_T1_SR_B3.TIF"},
+            "swir_1": {"path": "LE07_L2SP_090084_20210331_20210426_02_T1_SR_B5.TIF"},
+            "swir_2": {"path": "LE07_L2SP_090084_20210331_20210426_02_T1_SR_B7.TIF"},
+            "thermal_radiance": {
+                "path": "LE07_L2SP_090084_20210331_20210426_02_T1_ST_TRAD.TIF"
             },
-            "swir_1": {
-                "path": offset(
-                    l2_c2_ls8_folder,
-                    f"LE07_L2SP_090084_20210331_{processing_date}_0{leveln_collection}_T1_SR_B5.TIF",
-                )
-            },
-            "swir_2": {
-                "path": offset(
-                    l2_c2_ls8_folder,
-                    f"LE07_L2SP_090084_20210331_{processing_date}_0{leveln_collection}_T1_SR_B7.TIF",
-                )
+            "upwell_radiance": {
+                "path": "LE07_L2SP_090084_20210331_20210426_02_T1_ST_URAD.TIF"
             },
         },
         "accessories": {
             "metadata:landsat_mtl": {
-                "path": f"LE07_L2SP_090084_20210331_{processing_date}_0{leveln_collection}_T1_MTL.txt"
+                "path": "LE07_L2SP_090084_20210331_20210426_02_T1_MTL.txt"
             }
         },
-        "lineage": lineage or {},
+        "lineage": {},
     }
